//
// Copyright (c) 2012, MindFusion LLC - Bulgaria.
//

using System;
using System.Drawing;
using System.Drawing.Drawing2D;
using System.Windows.Forms;

using MindFusion.Drawing;

using HatchBrush = MindFusion.Drawing.HatchBrush;
using LinearGradientBrush = MindFusion.Drawing.LinearGradientBrush;
using SolidBrush = MindFusion.Drawing.SolidBrush;
using TextureBrush = MindFusion.Drawing.TextureBrush;


namespace MindFusion.Diagramming.WinForms.Samples.CS.PdfExporter
{
	public partial class MainForm : Form
	{
		public MainForm()
		{
			InitializeComponent();
		}

		private void Form1_Load(object sender, EventArgs e)
		{
			diagramView1.MouseWheel += new MouseEventHandler(diagramView1_MouseWheel);
			diagramView1.ShowScrollbars = true;

			ShapeNode node1 = diagram1.Factory.CreateShapeNode(23, 25, 24, 26);
            node1.Text = "This example demonstrates some of the <color=#ce0000><i>MindFusion.Diagramming</i></color> export capabilities.";
			node1.PolygonalTextLayout = true;
			node1.EnableStyledText = true;
            node1.Brush = new SolidBrush(Color.FromArgb(224, 233, 233));
            node1.Pen = new Drawing.Pen(Color.FromArgb(45, 57, 86));

			ShapeNode node2 = diagram1.Factory.CreateShapeNode(55, 25, 23, 22);
			node2.Text = "A node filled with a HatchBrush.";
            node2.Brush = new HatchBrush(HatchStyle.LightUpwardDiagonal, Color.FromArgb(45, 57, 86), Color.FromArgb(224, 233, 233));
			node2.Font = new Font("Courier", 10, FontStyle.Bold, GraphicsUnit.Point);
            node2.Pen = new Drawing.Pen(Color.FromArgb(45, 57, 86));

			ShapeNode node3 = diagram1.Factory.CreateShapeNode(85, 25, 22, 22);
			node3.Text = "A node filled with a SolidBrush.";
			node3.Brush = new SolidBrush(Color.FromArgb(102, 154, 204));
            node3.Pen = new Drawing.Pen(Color.FromArgb(45, 57, 86));

			ShapeNode node4 = diagram1.Factory.CreateShapeNode(55, 55, 22, 22);
			node4.Text = "A node filled with a gradient brush.";
			node4.Brush = new LinearGradientBrush(Color.FromArgb(224, 233, 233), Color.FromArgb(45, 57, 86), 30f);
            node4.Pen = new Drawing.Pen(Color.FromArgb(45, 57, 86));

			ShapeNode node5 = diagram1.Factory.CreateShapeNode(85, 55, 22, 22);
			node5.Text = "A node filled with a texture brush.";
			node5.Brush = new TextureBrush(pbTile.Image);
            node5.Pen = new Drawing.Pen(Color.FromArgb(45, 57, 86));
            node5.ImageAlign = ImageAlign.Stretch;
            node5.TextBrush = new SolidBrush(Color.FromArgb(224, 233, 233));

			ShapeNode node6 = diagram1.Factory.CreateShapeNode(115, 55, 24, 22);
			node6.Text = "And <b>some</b> <i>more</i> <color=#0000FF>formatted</color> text.";
			node6.PolygonalTextLayout = true;
			node6.EnableStyledText = true;
            node6.Brush = new SolidBrush(Color.FromArgb(156, 170, 198));
            node6.Pen = new Drawing.Pen(Color.FromArgb(45, 57, 86));
			node6.ShadowBrush = null;

			TableNode table1 = diagram1.Factory.CreateTableNode(10, 55, 38, 45);
			table1[0, 0].Text = "Member";
			table1[1, 0].Text = "Description";
            table1[0, 0].Brush = new SolidBrush(Color.FromArgb(102, 154, 204));
            table1[1, 0].Brush = new SolidBrush(Color.FromArgb(192, 192, 192));
            table1.Brush = new SolidBrush(Color.FromArgb(224, 233, 233));

			ContainerNode container1 = diagram1.Factory.CreateContainerNode(115, 5, 38, 45);

			diagram1.Factory.CreateDiagramLink(node1, node2);
			diagram1.Factory.CreateDiagramLink(node2, node3);
			diagram1.Factory.CreateDiagramLink(node3, node4);
			diagram1.Factory.CreateDiagramLink(node4, node5);
			diagram1.Factory.CreateDiagramLink(node5, node6);
            diagram1.DiagramLinkStyle.Stroke = new SolidBrush(Color.FromArgb(45, 57, 86));
            diagram1.DiagramLinkStyle.HeadStroke = new SolidBrush(Color.FromArgb(45, 57, 86));
		}

		private void button1_Click(object sender, EventArgs e)
		{
			saveFileDialog.DefaultExt = "pdf";
			saveFileDialog.Filter = "PDF files|*.pdf";
			if (saveFileDialog.ShowDialog() == DialogResult.OK)
			{
				MindFusion.Diagramming.Export.PdfExporter pdfExp =
					new MindFusion.Diagramming.Export.PdfExporter();
				pdfExp.Export(diagramView1.Diagram, saveFileDialog.FileName);
			}
		}

		private void diagram1_DrawBackground(object sender, MindFusion.Diagramming.DiagramEventArgs e)
		{
			Font font = new Font("Arial", 4, GraphicsUnit.World);
            System.Drawing.Brush brush = new System.Drawing.SolidBrush(Color.FromArgb(206, 0, 0));
            System.Drawing.Pen pen = new System.Drawing.Pen(Color.FromArgb(102, 154, 204), 0);

			RectangleF rect = new RectangleF(0, 0, 40, 30);
            e.Graphics.FillRectangle(new System.Drawing.SolidBrush(Color.FromArgb(224, 233, 233)), rect.X, rect.Y, rect.Width, rect.Height);
			e.Graphics.DrawRectangle(pen, rect.X, rect.Y, rect.Width, rect.Height);
			e.Graphics.DrawString("Custom-drawn graphic elements are exported to PDF and SVG too!",
				font, brush, rect);

			brush.Dispose();
			pen.Dispose();
			font.Dispose();
		}

		private void btnSvgExport_Click(object sender, System.EventArgs e)
		{
			saveFileDialog.DefaultExt = "svg";
			saveFileDialog.Filter = "SVG files|*.svg";
			if (saveFileDialog.ShowDialog() == DialogResult.OK)
			{
				MindFusion.Diagramming.Export.SvgExporter svgExp =
					new MindFusion.Diagramming.Export.SvgExporter();
				svgExp.ExternalImages = false;
				svgExp.Export(diagramView1.Diagram, saveFileDialog.FileName);
			}
		}

		private void btnPngExport_Click(object sender, System.EventArgs e)
		{
			saveFileDialog.DefaultExt = "png";
			saveFileDialog.Filter = "PNG files|*.png";
			if (saveFileDialog.ShowDialog() == DialogResult.OK)
			{
				Image image = diagram1.CreateImage();
				image.Save(saveFileDialog.FileName);
				image.Dispose();
			}
		}

		private void diagramView1_MouseWheel(object sender, MouseEventArgs e)
		{
			diagramView1.ZoomFactor += e.Delta / 40;
		}
	}
}